Electron Microscopy Beam (EMBeam)
=================================

``embeam`` is a Python library for for modelling beams and lenses in electron
microscopy.

The source code can be found in the `embeam GitHub repository
<https://github.com/mrfitzpa/embeam>`_.



Instructions for installing and uninstalling ``embeam``
-------------------------------------------------------

For instructions on installing the ``embeam`` library, see the
:ref:`installation_instructions_sec` page.


     
Learning how to use ``embeam``
------------------------------

For those new to the ``embeam`` library, it is recommended that they take a look
at the :ref:`examples_sec` page, which contain code examples that show how one
can use the ``embeam`` library. While going through the examples, readers can
consult the :ref:`reference_guide_sec` to understand what each line of code is
doing.



Contents
--------

.. toctree::
   :maxdepth: 6
   :numbered:

   Home <self>
   INSTALL
   Reference <_autosummary/embeam>
   examples
   license


   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
